analytic

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2019 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanUp

func CleanUp()

*

  • CleanUp makes sure, that all events have been trasmittet prior to ending the process.

func GetHostname

func GetHostname() string

*

  • GetHostname gets the hostname ...

func GetSystemLocale

func GetSystemLocale() (string, error)

*

  • Get System Locale

func InitializeAnalytics

func InitializeAnalytics(appName string, appVersion string)

*

func TriggerEvent

func TriggerEvent(eventName string, eventPayload string)

*

  • TriggerEvent triggers a tracked Event which will be visible in analytics

Types

This section is empty.

Jump to